@@ -1,15 +1,18 @@
 """DLsite Async."""
+from . import exceptions, utils
 from .api import DlsiteAPI
 from .circle import Circle, MakerType
 from .work import AgeCategory, BookType, Work, WorkType
 
 
 __all__ = [
-    "DlsiteAPI",
     "AgeCategory",
     "BookType",
-    "WorkType",
-    "Work",
     "Circle",
+    "DlsiteAPI",
     "MakerType",
+    "Work",
+    "WorkType",
+    "exceptions",
+    "utils",
 ]
