@@ -6,7 +6,7 @@ from typing import Any, Mapping
 from .exceptions import InvalidIDError
 
 
-class MakerType(Enum):
+class MakerType(str, Enum):
     """Maker type."""
 
     BRAND = "brand"
@@ -20,10 +20,11 @@ class MakerType(Enum):
         Arguments:
             maker_id: Maker ID
 
-        Returns: Maker type.
+        Returns:
+            Maker type.
 
         Raises:
-            InvalidIDError: maker_id was invalid.
+            InvalidIDError: `maker_id` was invalid.
         """
         if maker_id[:2] == "RG":
             return MakerType.CIRCLE
